
% ============================================================
% Function used in stokesInput.m to compute plane value
% ============================================================
% Master's thesis: Modelling of Ringing Loads on Offshore Wind
% Turbine monopiles
% Department of Marine Technology, NTNU
% Spring 2020
% ============================================================
% Modified: Vilde Mathisen, 15.05.20
% ============================================================


function [dudt dudz k u] = stokes5thWaves_planeValue(h,T,steep,Nper,z_strip,t)

g = 9.81;                % Gravity constant [m/s^2]

x = 0;                     % x-coordinate [m]
Ntper = 50;               % Discretization of wave period [no]

%% Angular velocity 
omega = 2*pi/T;
    
 %% Compute wave number k and parameter gamma
kw1 = findk(T,h);
za1 = pi/(kw1*steep);
H   = 2*za1;
k = kw1;
za = za1;
gamma = k*za;

%% Compute Skjelbreia constants
[A11 A13 A15 A22 A24 A33 A35 A44 A55 B22 B24 B33 B35 B44 B55 C1 C2 C3 C4] ...
     = computeSkjelbreiaConstants(k,h);
 
%% Coefficients for velocity potential and surface profile
D1 = omega/k^2*(gamma*A11 + gamma^3*A13 + gamma^5*A15);
D2 = omega/k^2*(gamma^2*A22 + gamma^4*A24);
D3 = omega/k^2*(gamma^3*A33 + gamma^5*A35);
D4 = omega/k^2*(gamma^4*A44);
D5 = omega/k^2*(gamma^5*A55);

E1 = gamma;
E2 = gamma^2*B22 + gamma^4*B24;
E3 = gamma^3*B33 + gamma^5*B35;
E4 = gamma^4*B44; 
E5 = gamma^5*B55;

%% Phase angle
th  = k*x - omega*t;

%% Surface profile
  zeta = 1/k*(E1*cos(th) + ...
    E2*cos(2*th) + ...
    E3*cos(3*th) + ...
    E4*cos(4*th) + ...
    E5*cos(5*th));

%% Wave celerity C
C0 = g*(tanh(k*h));
C = ((g*tanh(h*k)*(C2*gamma^4 + C1*gamma^2 + 1))/k)^(1/2);

if z_strip <= 0
%% Velocities, acceleration and velocity gradients for z <= 0
[u,w,dudt,dudx,dudz] = computeVelocities(omega,k,g,h,x, ...
    D1,D2,D3,D4,D5,E1,E2,E3,E4,E5,C,z_strip,t);
elseif z_strip > 0
[u,w,dudt,dudx,dudz] = taylorExpansion(omega,k,h,D1,D2,D3, ...
    D4,D5,C,x,z_strip,t);
end

end